@@ -540,9 +540,9 @@ class TestF5Converter:
                          file_attribute['controller_password_17_1_1'],
                          file_attribute['controller_version_v17'],
                          file_attribute['license_file_path'])
-            print "Controller is running properly."
+            print("Controller is running properly.")
         else:
-            print "Controller is not running properly."
+            print("Controller is not running properly.")
 
     @pytest.mark.skip_travis
     @pytest.mark.TCID1_48_1497_26_0
@@ -579,9 +579,9 @@ class TestF5Converter:
                          file_attribute['controller_password_17_1_1'],
                          file_attribute['controller_version_v17'],
                          file_attribute['license_file_path'])
-            print "Controller is running properly."
+            print("Controller is running properly.")
         else:
-            print "Controller is not running properly."
+            print("Controller is not running properly.")
 
     @pytest.mark.skip_travis
     @pytest.mark.TCID1_48_1497_28_0
@@ -619,9 +619,9 @@ class TestF5Converter:
                          file_attribute['controller_password_17_1_1'],
                          file_attribute['controller_version_v17'],
                          file_attribute['license_file_path'])
-            print "Controller is running properly."
+            print("Controller is running properly.")
         else:
-            print "Controller is not running properly."
+            print("Controller is not running properly.")
 
     @pytest.mark.skip_travis
     @pytest.mark.TCID1_48_1497_30_0
@@ -678,9 +678,9 @@ class TestF5Converter:
                          file_attribute['controller_password_17_1_1'],
                          file_attribute['controller_version_v17'],
                          file_attribute['license_file_path'])
-            print "Controller is running properly."
+            print("Controller is running properly.")
         else:
-            print "Controller is not running properly."
+            print("Controller is not running properly.")
 
     @pytest.mark.skip_travis
     @pytest.mark.TCID1_48_1497_33_0
@@ -979,7 +979,7 @@ class TestF5Converter:
                     '&')[0]
                 script_set = [data['name'] for data in vs_datascript if
                               data['name'] == ds_name][0]
-                print script_set, " ", ds_name
+                print(script_set, " ", ds_name)
                 assert script_set == ds_name
 
             vs_data = [data for data in vs_object if data['name']
@@ -990,7 +990,7 @@ class TestF5Converter:
                     '&')[0]
                 httppolicy = [data['name'] for data in http_policy_set
                               if data['name'] == policy_name][0]
-                print policy_name, " ", httppolicy
+                print(policy_name, " ", httppolicy)
                 assert policy_name == httppolicy
 
             vs_data_for_policy_set = [data for data in vs_object if
@@ -1001,7 +1001,7 @@ class TestF5Converter:
                     '&')[0]
                 script_set = [data['name'] for data in vs_datascript
                               if data['name'] == ds_name][0]
-                print script_set, " ", ds_name
+                print(script_set, " ", ds_name)
                 assert script_set == ds_name
 
             vs_data = [data for data in vs_object if data['name'] == "EngVIP"]
@@ -1013,7 +1013,7 @@ class TestF5Converter:
                     httppolicy = [data['name'] for data in http_policy_set if
                                   data['name'] == policy_name
                                   and '_sys_https_redirect-EngVIP'][0]
-                    print policy_name, " ", httppolicy
+                    print(policy_name, " ", httppolicy)
                     assert policy_name == httppolicy
 
             vs_data = [data for data in vs_object if data['name'] == "vs1"]
@@ -1053,7 +1053,7 @@ class TestF5Converter:
                 httppolicy = [data['name'] for data in http_policy_set if
                               data['name'] == policy_name and
                               'Test-support-Profile-HTTP-HTTP-Policy-Set'][0]
-                print policy_name, " ", httppolicy
+                print(policy_name, " ", httppolicy)
                 assert policy_name == httppolicy
 
         vs_data = [data for data in vs_object if data['name']
@@ -1113,9 +1113,9 @@ class TestF5Converter:
                          file_attribute['controller_password_17_1_1'],
                          file_attribute['controller_version_v17'],
                          file_attribute['license_file_path'])
-            print "Controller is running properly."
+            print("Controller is running properly.")
         else:
-            print "Controller is not running properly."
+            print("Controller is not running properly.")
 
     @pytest.mark.skip_travis
     @pytest.mark.TCID1_48_1497_51_0
@@ -1169,9 +1169,9 @@ class TestF5Converter:
                          file_attribute['controller_password_17_1_1'],
                          file_attribute['controller_version_v17'],
                          file_attribute['license_file_path'])
-            print "Controller is running properly."
+            print("Controller is running properly.")
         else:
-            print "Controller is not running properly."
+            print("Controller is not running properly.")
 
     @pytest.mark.skip_travis
     @pytest.mark.TCID1_48_1497_54_0
@@ -1220,9 +1220,9 @@ class TestF5Converter:
                          file_attribute['controller_password_17_1_1'],
                          file_attribute['controller_version_v17'],
                          file_attribute['license_file_path'])
-            print "Controller is running properly."
+            print("Controller is running properly.")
         else:
-            print "Controller is not running properly."
+            print("Controller is not running properly.")
 
     @pytest.mark.skip_travis
     @pytest.mark.TCID1_48_1497_56_0
@@ -1403,7 +1403,7 @@ class TestF5Converter:
             if policy_name == "req_pol_rule-F5-VIP-443-004":
                 httppolicy = [data['name'] for data in http_policy_set if
                               data['name'] == policy_name][0]
-                print policy_name, " ", httppolicy
+                print(policy_name, " ", httppolicy)
                 assert policy_name == httppolicy
 
         for i in httppolicydata2:
@@ -1412,7 +1412,7 @@ class TestF5Converter:
             if policy_name == "req_pol_rule-F5-VIP-443-004":
                 httppolicy = [data['name'] for data in http_policy_set if
                               data['name'] == policy_name][0]
-                print policy_name, " ", httppolicy
+                print(policy_name, " ", httppolicy)
                 assert policy_name == httppolicy
 
     @pytest.mark.travis
@@ -1569,30 +1569,5 @@ class TestF5Converter:
             assert expected_cert, "Expected cert monitor.fmr.com.crt not found"
             assert expected_ssl_profile, "Expected ssl profile monitor.fmr.com not found"
 
-    @pytest.mark.travis
-    def test_monitor_ref_on_v11(self):
-        f5_conv(bigip_config_file=setup.get('config_file_name_v11'),
-                f5_config_version=setup.get('file_version_v11'),
-                controller_version=setup.get('controller_version_v17'),
-                tenant=file_attribute['tenant'],
-                cloud_name=file_attribute['cloud_name'],
-                no_profile_merge=file_attribute['no_profile_merge'],
-                output_file_path=setup.get('output_file_path'),
-                vs_filter="vs_http_policy_share_1"
-                )
-        o_file = "%s/%s" % (output_file, "bigip_v11-Output.json")
-        with open(o_file) as json_file:
-          data = json.load(json_file)
-          pool_object = data['Pool'][0]
-          vs_object = data['VirtualService'][0]
-          poolRef = vs_object.get('pool_ref')
-          vsPoolRef = poolRef.split('name=')[1].split('&')[0]
-          pNmae = pool_object.get('name')
-          hMonitor = pool_object.get('health_monitor_refs')[0]
-          mName = hMonitor.split('name=')[1]
-          assert vsPoolRef == pNmae
-          assert mName == "tcp"
-
-
 def teardown():
     pass
